==> haskell-keys-3.12.2-29-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-keys.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: keys
version: 3.12.2
id: keys-3.12.2-IL3h5CEQiE1CLh2TlrHJ6s
key: keys-3.12.2-IL3h5CEQiE1CLh2TlrHJ6s
license: BSD-3-Clause
copyright: Copyright (C) 2011-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/keys/
synopsis: Keyed functors and containers
description:
    This package provides a bunch of ad hoc classes for accessing parts of a container.
    .
    In practice this package is largely subsumed by the
    <https://hackage.haskell.org/package/lens lens package>,
    but it is maintained for now as it has much
    simpler dependencies.
category: Data Structures, Containers
abi: c94a159fa71529314f7dd4e6326649b0
exposed: True
exposed-modules:
    Data.Key
import-dirs: /usr/lib/ghc-8.6.5/site-local/keys-3.12.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/keys-3.12.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/keys-3.12.2
hs-libraries: HSkeys-3.12.2-IL3h5CEQiE1CLh2TlrHJ6s
depends:
    array-0.5.3.0 base-4.12.0.0 comonad-5.0.6-8rsrtEd0xc7Zvn1LuwTgB
    containers-0.6.0.1 free-5.1.2-6EqrYTKjKSl2dnY4P2nHLx
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    semigroupoids-5.3.3-AQtiKPqhF0dKZgZBy40uPE
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    unordered-containers-0.2.10.0-AdFIXUUlSRM50nV4OuQt9A
haddock-interfaces: /usr/share/doc/haskell-keys/html/keys.haddock
haddock-html: /usr/share/doc/haskell-keys/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-keys-3.12.2-30-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-keys.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: keys
version: 3.12.2
id: keys-3.12.2-BL7u9Su2d6dDTR3PsOs1am
key: keys-3.12.2-BL7u9Su2d6dDTR3PsOs1am
license: BSD-3-Clause
copyright: Copyright (C) 2011-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/keys/
synopsis: Keyed functors and containers
description:
    This package provides a bunch of ad hoc classes for accessing parts of a container.
    .
    In practice this package is largely subsumed by the
    <https://hackage.haskell.org/package/lens lens package>,
    but it is maintained for now as it has much
    simpler dependencies.
category: Data Structures, Containers
abi: acfbcab261f68dd43e675fc26fd54658
exposed: True
exposed-modules:
    Data.Key
import-dirs: /usr/lib/ghc-8.6.5/site-local/keys-3.12.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/keys-3.12.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/keys-3.12.2
hs-libraries: HSkeys-3.12.2-BL7u9Su2d6dDTR3PsOs1am
depends:
    array-0.5.3.0 base-4.12.0.0 comonad-5.0.6-8rsrtEd0xc7Zvn1LuwTgB
    containers-0.6.0.1 free-5.1.3-16riWRkMrEyBwwRAzko3GF
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    semigroupoids-5.3.3-AQtiKPqhF0dKZgZBy40uPE
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    unordered-containers-0.2.10.0-AdFIXUUlSRM50nV4OuQt9A
haddock-interfaces: /usr/share/doc/haskell-keys/html/keys.haddock
haddock-html: /usr/share/doc/haskell-keys/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
